@@ -1,6 +1,7 @@
 
 # Note: explicitly set environment variable NOT_CRAN to "true" (e.g. on command line) to run skipped tests
 
+source("helper.R")
 
 # Make temp directory to store images from web
 outdir_dicom = tempfile(tmpdir = tempdir(check = TRUE))
@@ -22,8 +23,8 @@ sbarre_url_sample <- function(sample) {paste(url_sbarre, sample, ".gz", sep = ""
 sbarre_unzip_file <- function(sample) {xfun::normalize_path(file.path(outdir_dicom, sample))}
 sbarre_zip_file <- function(sample) {paste(sbarre_unzip_file(sample), ".gz", sep = "")}
 for(sample in sbarre_samples) {
-  download.file(sbarre_url_sample(sample), sbarre_zip_file(sample))
-  R.utils::gunzip(sbarre_zip_file(sample))
+  dl_try(sbarre_url_sample(sample), sbarre_zip_file(sample))
+  if(file.exists(sbarre_zip_file(sample))) R.utils::gunzip(sbarre_zip_file(sample))
 }
 
 # dicom_data_sbarre_ort
@@ -42,7 +43,7 @@ for(sample in sbarre_samples) {
 # - Can't make 3D matrix with single slice
 # - Test specific header values
 # - Dimensions of metadata matrix
-dicom_data_sbarre_ort <- read_dicom(sbarre_unzip_file(sbarre_samples$ort))
+dicom_data_sbarre_ort <- read_dicom_try(sbarre_unzip_file(sbarre_samples$ort))
 
 # dicom_data_sbarre_brain
 # - DICOM
@@ -59,7 +60,7 @@ dicom_data_sbarre_ort <- read_dicom(sbarre_unzip_file(sbarre_samples$ort))
 # - Slice thickness
 # - Dimensions of metadata matrix
 # - View slice of 2D image
-dicom_data_sbarre_brain <- read_dicom(sbarre_unzip_file(sbarre_samples$brain))
+dicom_data_sbarre_brain <- read_dicom_try(sbarre_unzip_file(sbarre_samples$brain))
 
 # dicom_data_sbarre_head
 # - DICOM
@@ -74,7 +75,7 @@ dicom_data_sbarre_brain <- read_dicom(sbarre_unzip_file(sbarre_samples$brain))
 # - Has a single slice
 # - Spatial resolution
 # - Manufacturer
-dicom_data_sbarre_head <- read_dicom(sbarre_unzip_file(sbarre_samples$head))
+dicom_data_sbarre_head <- read_dicom_try(sbarre_unzip_file(sbarre_samples$head))
 
 # dicom_data_sbarre_knee
 # - DICOM
@@ -88,7 +89,7 @@ dicom_data_sbarre_head <- read_dicom(sbarre_unzip_file(sbarre_samples$head))
 # Aspects tested:
 # - Has a single slice
 # - Specific metadata values
-dicom_data_sbarre_knee <- read_dicom(sbarre_unzip_file(sbarre_samples$knee))
+dicom_data_sbarre_knee <- read_dicom_try(sbarre_unzip_file(sbarre_samples$knee))
 
 # dicom_data_sbarre_heart_mr
 # - A 3D DICOM image stored in a single file instead of one slice per file
@@ -106,7 +107,7 @@ dicom_data_sbarre_knee <- read_dicom(sbarre_unzip_file(sbarre_samples$knee))
 # - dicom_header_as_matrix can't specify slice if multiple slices in single image file
 # - Dimensions of metadata matrix
 # - Conversion to 3D matrix fails due to missing header fields ImagePositionPatient, ImageOrientationPatient
-dicom_data_sbarre_heart_mr <- read_dicom(sbarre_unzip_file(sbarre_samples$heart_mr))
+dicom_data_sbarre_heart_mr <- read_dicom_try(sbarre_unzip_file(sbarre_samples$heart_mr))
 
 # dicom_data_sbarre_heart_nm
 # - DICOM
@@ -122,7 +123,7 @@ dicom_data_sbarre_heart_mr <- read_dicom(sbarre_unzip_file(sbarre_samples$heart_
 # - Number of frames (13)
 # - Set of header fields
 # - Conversion to 3D matrix fails due to missing header fields ImagePositionPatient, ImageOrientationPatient
-dicom_data_sbarre_heart_nm <- read_dicom(sbarre_unzip_file(sbarre_samples$heart_nm))
+dicom_data_sbarre_heart_nm <- read_dicom_try(sbarre_unzip_file(sbarre_samples$heart_nm))
 
 # dicom_data_sbarre_execho
 # - DICOM
@@ -136,7 +137,7 @@ dicom_data_sbarre_heart_nm <- read_dicom(sbarre_unzip_file(sbarre_samples$heart_
 # - Number of frames
 # - Set of header fields
 # - Some calculations fail due to missing header fields ImagePositionPatient, ImageOrientationPatient
-dicom_data_sbarre_execho <- read_dicom(sbarre_unzip_file(sbarre_samples$execho))
+dicom_data_sbarre_execho <- read_dicom_try(sbarre_unzip_file(sbarre_samples$execho))
 
 
 # Function to expand a .tar.bz2 archive
@@ -151,12 +152,12 @@ expand_tar_bz2 <- function(file, outdir) {
 d_clunie_tar_charset <- xfun::normalize_path(file.path(outdir_dicom, "charsettests.20070405.tar.bz2"))
 d_clunie_tar_deflate <- xfun::normalize_path(file.path(outdir_dicom, "deflate_tests_release.tar.gz"))
 d_clunie_tar_signedrange <- xfun::normalize_path(file.path(outdir_dicom, "signedrangeimages.tar.bz2"))
-download.file("http://www.dclunie.com/images/charset/charsettests.20070405.tar.bz2", d_clunie_tar_charset)
-download.file("http://www.dclunie.com/images/compressed/deflate_tests_release.tar.gz", d_clunie_tar_deflate)
-download.file("http://www.dclunie.com/images/signedrange/signedrangeimages.tar.bz2", d_clunie_tar_signedrange)
-untar(d_clunie_tar_deflate, exdir = outdir_dicom)
-expand_tar_bz2(d_clunie_tar_charset, outdir_dicom)
-expand_tar_bz2(d_clunie_tar_signedrange, outdir_dicom)
+dl_try("http://www.dclunie.com/images/charset/charsettests.20070405.tar.bz2", d_clunie_tar_charset)
+dl_try("http://www.dclunie.com/images/compressed/deflate_tests_release.tar.gz", d_clunie_tar_deflate)
+dl_try("http://www.dclunie.com/images/signedrange/signedrangeimages.tar.bz2", d_clunie_tar_signedrange)
+if (file.exists(d_clunie_tar_deflate)) untar(d_clunie_tar_deflate, exdir = outdir_dicom)
+if (file.exists(d_clunie_tar_charset)) expand_tar_bz2(d_clunie_tar_charset, outdir_dicom)
+if (file.exists(d_clunie_tar_signedrange)) expand_tar_bz2(d_clunie_tar_signedrange, outdir_dicom)
 dir_d_clunie_dicom_deflate <- xfun::normalize_path(file.path(outdir_dicom, "deflate_tests"))
 dir_d_clunie_dicom_charset <- xfun::normalize_path(file.path(outdir_dicom, "charsettests"))
 dir_d_clunie_dicom_signedrange <- xfun::normalize_path(file.path(outdir_dicom, "IMAGES"))
@@ -182,11 +183,11 @@ print_dir <- function(dir) {
 # - Single slice
 # - Specific header fields and values
 # - Set of header fields
-dicom_data_dclunie_scsgreek <- read_dicom(xfun::normalize_path(file.path(dir_d_clunie_dicom_charset, "SCSGREEK")))
+dicom_data_dclunie_scsgreek <- read_dicom_try(xfun::normalize_path(file.path(dir_d_clunie_dicom_charset, "SCSGREEK")))
 
 # Aspects tested:
 # - Some calculations fail due to missing header fields ImagePositionPatient, ImageOrientationPatient
-dicom_data_dclunie_scsx2 <- read_dicom(xfun::normalize_path(file.path(dir_d_clunie_dicom_charset, "SCSX2")))
+dicom_data_dclunie_scsx2 <- read_dicom_try(xfun::normalize_path(file.path(dir_d_clunie_dicom_charset, "SCSX2")))
 
 # dicom_data_dclunie_image
 # - Deflate transfer syntax
@@ -197,13 +198,70 @@ dicom_data_dclunie_scsx2 <- read_dicom(xfun::normalize_path(file.path(dir_d_clun
 # - Has invalid metadata according to current DICOM standard
 # - Study instance UID
 # - Some calculations fail due to missing header fields ImagePositionPatient, ImageOrientationPatient
-dicom_data_dclunie_image <- read_dicom(xfun::normalize_path(file.path(dir_d_clunie_dicom_deflate, "image")))
+dicom_data_dclunie_image <- read_dicom_try(xfun::normalize_path(file.path(dir_d_clunie_dicom_deflate, "image")))
 
 
 # TCIA datasets can't be downloaded on the fly
 # PCIR datasets take a long time to download, so skip them on CRAN
 if(identical(tolower(Sys.getenv("NOT_CRAN")), "true")) {
 
+  # Images from patient contributed image repository http://www.pcir.org/
+
+  pcir_tar_988 <- paste(outdir_dicom, "98890234_20030505_MR.tar.bz2", sep = "")
+  pcir_tar_247 <- paste(outdir_dicom, "24759123_20010101.tar.bz2", sep = "")
+  dl_try("https://archive.org/download/9889023420030505MR/98890234_20030505_MR.tar.bz2", pcir_tar_988)
+  dl_try("https://archive.org/download/2475912320010101/24759123_20010101.tar.bz2", pcir_tar_247)
+  if (file.exists(pcir_tar_988)) expand_tar_bz2(pcir_tar_988, outdir_dicom)
+  if (file.exists(pcir_tar_247)) expand_tar_bz2(pcir_tar_247, outdir_dicom)
+  # 98890234_20030505_MR
+  # MR, MRA, DWI of Brain, Carotids
+  dir_pcir_988 <- xfun::normalize_path(file.path(outdir_dicom, "98890234/20030505/MR/"))
+  # 24759123_20010101
+  # Patient contributed DICOM images - MR, MRA, DWI of Brain, Carotids
+  dir_pcir_247 <- xfun::normalize_path(file.path(outdir_dicom, "24759123/20010101/"))
+  #print_dir(dir_pcir_988)
+  #print_dir(dir_pcir_247)
+
+  # dicom_data_988_MR700
+  # Aspects tested:
+  # - Has 12 slices
+  # - Dimensions of metadata matrix
+  # - Image dimensions 512x512x12
+  # - SOP class UID
+  # - MediaStorageSOPInstanceUID is a list
+  # - Constant header values across slices is a list; specific constant values
+  # - Constant header value list elements have appropriate type
+  # - Metadata matrix dimensions
+  # - Convert image data to 3D matrix; correct dimensions
+  # - When converting image data to 3D matrix, can't use option to hold additional dimensions constant because there are no additional dimensions
+  dicom_data_988_MR700 <- read_dicom_try(xfun::normalize_path(file.path(dir_pcir_988, "MR700")))
+
+
+  # dicom_data_247_MR3
+  # - A DICOM image with 24 slices, where image file dimensions do not match Rows and Columns attributes in DICOM metadata
+  # Aspects tested:
+  # - Can make 3D matrix despite discrepancy in image dimension attributes; code raises a warning in this case
+  # - Has 24 slices
+  # - Constant header values across slices: a list with names = the header names; specific values
+  # - Constant header values list elements have appropriate type
+  # - Header value is a list with one entry per slice; specific values
+  # - Header value list elements have appropriate type e.g. numeric
+  # - Metadata matrix has 28 columns
+  # - Set of header fields
+  # - When converting image data to 3D matrix, can't use option to hold additional dimensions constant because there are no additional dimensions
+  dicom_data_247_MR3 <- read_dicom_try(xfun::normalize_path(file.path(dir_pcir_247, "MR3")))
+
+  # dicom_data_247_OT
+  # -
+  # Aspects tested:
+  # - Header value for image type
+  # - Value for DerivationDescription is constant across slices and has appropriate type when retrieved
+  # - Has a single slice
+  # - Metadata matrix dimensions
+  # - Set of header fields; specific fields are present
+  # - Some calculations fail due to missing fields ImagePositionPatient and ImageOrientationPatient
+  dicom_data_247_OT <- read_dicom_try(xfun::normalize_path(file.path(dir_pcir_247, "OT999999")))
+
 
   # dicom_data_qin_hn_sr
   # - Series 1.2.276.0.7230010.3.1.3.8323329.18438.1440001309.981882 from TCIA
@@ -224,11 +282,10 @@ if(identical(tolower(Sys.getenv("NOT_CRAN")), "true")) {
     dir_qin_headneck_sr = tempfile()
     dir.create(dir_qin_headneck_sr, showWarnings = FALSE)
     files = unzip(res$out_file, exdir = dir_qin_headneck_sr)
-  } else {
-    testthat::skip_on_travis()
-    testthat::skip_on_appveyor()
   }
-  dicom_data_qin_hn_sr <- read_dicom(xfun::normalize_path(file.path(dir_qin_headneck_sr, "1-234.dcm")))
+  if (dir.exists(dir_qin_headneck_sr)) {
+    dicom_data_qin_hn_sr <- read_dicom_try(xfun::normalize_path(file.path(dir_qin_headneck_sr, "1-234.dcm")))
+  }
 
   # dicom_data_prostate_mr
   # - NCI ISBI prostate challenge
@@ -264,18 +321,17 @@ if(identical(tolower(Sys.getenv("NOT_CRAN")), "true")) {
   # - Error when trying to view slice of 3D intensity matrix that is out of bounds
   dir_prostate_dicom_mr <- "~/Dropbox/Documents/Radiogenomics/radiogenomics_r_package/sample_data/images/dicom/nci_isbi_2013_challenge_prostate/images_dicom/"
   dir_prostate_dicom_mr = file.path(dir_prostate_dicom_mr,
-              "Prostate3T-03-0001/1.3.6.1.4.1.14519.5.2.1.7307.2101.182382809090179976301292139745/1.3.6.1.4.1.14519.5.2.1.7307.2101.287009217605941401146066177219")
+                                    "Prostate3T-03-0001/1.3.6.1.4.1.14519.5.2.1.7307.2101.182382809090179976301292139745/1.3.6.1.4.1.14519.5.2.1.7307.2101.287009217605941401146066177219")
   dir_prostate_dicom_mr <- xfun::normalize_path(dir_prostate_dicom_mr)
   if (have_api_key) {
     res = TCIApathfinder::save_image_series("1.3.6.1.4.1.14519.5.2.1.7307.2101.287009217605941401146066177219")
     dir_prostate_dicom_mr = tempfile()
     dir.create(dir_prostate_dicom_mr, showWarnings = FALSE)
     files = unzip(res$out_file, exdir = dir_prostate_dicom_mr)
-  } else {
-    testthat::skip_on_travis()
-    testthat::skip_on_appveyor()
   }
-  dicom_data_prostate_mr <- read_dicom(dir_prostate_dicom_mr)
+  if (dir.exists(dir_prostate_dicom_mr)) {
+    dicom_data_prostate_mr <- read_dicom_try(dir_prostate_dicom_mr)
+  }
 
   # dicom_data_chest
   # - LIDC-IDRI
@@ -300,11 +356,10 @@ if(identical(tolower(Sys.getenv("NOT_CRAN")), "true")) {
     dir_chest_dicom = tempfile()
     dir.create(dir_chest_dicom, showWarnings = FALSE)
     files = unzip(res$out_file, exdir = dir_chest_dicom)
-  } else {
-    testthat::skip_on_travis()
-    testthat::skip_on_appveyor()
   }
-  dicom_data_chest <- read_dicom(dir_chest_dicom)
+  if (dir.exists(dir_chest_dicom)) {
+    dicom_data_chest <- read_dicom_try(dir_chest_dicom)
+  }
 
   # dicom_data_prostate_pt
   # - NaF Prostate
@@ -324,11 +379,10 @@ if(identical(tolower(Sys.getenv("NOT_CRAN")), "true")) {
     dir_prostate_pt_dicom = tempfile()
     dir.create(dir_prostate_pt_dicom, showWarnings = FALSE)
     files = unzip(res$out_file, exdir = dir_prostate_pt_dicom)
-  } else {
-    testthat::skip_on_travis()
-    testthat::skip_on_appveyor()
   }
-  dicom_data_prostate_pt <- read_dicom(dir_prostate_pt_dicom)
+  if (dir.exists(dir_prostate_pt_dicom)) {
+    dicom_data_prostate_pt <- read_dicom_try(dir_prostate_pt_dicom)
+  }
 
   # dicom_data_bladder
   # - TCIA image with a single slice
@@ -354,67 +408,9 @@ if(identical(tolower(Sys.getenv("NOT_CRAN")), "true")) {
     dir_bladder_dicom = tempfile()
     dir.create(dir_bladder_dicom, showWarnings = FALSE)
     files = unzip(res$out_file, exdir = dir_bladder_dicom)
-  } else {
-    testthat::skip_on_travis()
-    testthat::skip_on_appveyor()
   }
-  dicom_data_bladder <- read_dicom(dir_bladder_dicom)
-
-  # Images from patient contributed image repository http://www.pcir.org/
-
-  pcir_tar_988 <- paste(outdir_dicom, "98890234_20030505_MR.tar.bz2", sep = "")
-  pcir_tar_247 <- paste(outdir_dicom, "24759123_20010101.tar.bz2", sep = "")
-  download.file("https://archive.org/download/9889023420030505MR/98890234_20030505_MR.tar.bz2", pcir_tar_988)
-  download.file("https://archive.org/download/2475912320010101/24759123_20010101.tar.bz2", pcir_tar_247)
-  expand_tar_bz2(pcir_tar_988, outdir_dicom)
-  expand_tar_bz2(pcir_tar_247, outdir_dicom)
-  # 98890234_20030505_MR
-  # MR, MRA, DWI of Brain, Carotids
-  dir_pcir_988 <- xfun::normalize_path(file.path(outdir_dicom, "98890234/20030505/MR/"))
-  # 24759123_20010101
-  # Patient contributed DICOM images - MR, MRA, DWI of Brain, Carotids
-  dir_pcir_247 <- xfun::normalize_path(file.path(outdir_dicom, "24759123/20010101/"))
-  #print_dir(dir_pcir_988)
-  #print_dir(dir_pcir_247)
-
-  # dicom_data_988_MR700
-  # Aspects tested:
-  # - Has 12 slices
-  # - Dimensions of metadata matrix
-  # - Image dimensions 512x512x12
-  # - SOP class UID
-  # - MediaStorageSOPInstanceUID is a list
-  # - Constant header values across slices is a list; specific constant values
-  # - Constant header value list elements have appropriate type
-  # - Metadata matrix dimensions
-  # - Convert image data to 3D matrix; correct dimensions
-  # - When converting image data to 3D matrix, can't use option to hold additional dimensions constant because there are no additional dimensions
-  dicom_data_988_MR700 <- read_dicom(xfun::normalize_path(file.path(dir_pcir_988, "MR700")))
-
-
-  # dicom_data_247_MR3
-  # - A DICOM image with 24 slices, where image file dimensions do not match Rows and Columns attributes in DICOM metadata
-  # Aspects tested:
-  # - Can make 3D matrix despite discrepancy in image dimension attributes; code raises a warning in this case
-  # - Has 24 slices
-  # - Constant header values across slices: a list with names = the header names; specific values
-  # - Constant header values list elements have appropriate type
-  # - Header value is a list with one entry per slice; specific values
-  # - Header value list elements have appropriate type e.g. numeric
-  # - Metadata matrix has 28 columns
-  # - Set of header fields
-  # - When converting image data to 3D matrix, can't use option to hold additional dimensions constant because there are no additional dimensions
-  dicom_data_247_MR3 <- read_dicom(xfun::normalize_path(file.path(dir_pcir_247, "MR3")))
-
-  # dicom_data_247_OT
-  # -
-  # Aspects tested:
-  # - Header value for image type
-  # - Value for DerivationDescription is constant across slices and has appropriate type when retrieved
-  # - Has a single slice
-  # - Metadata matrix dimensions
-  # - Set of header fields; specific fields are present
-  # - Some calculations fail due to missing fields ImagePositionPatient and ImageOrientationPatient
-  dicom_data_247_OT <- read_dicom(xfun::normalize_path(file.path(dir_pcir_247, "OT999999")))
+  if (dir.exists(dir_bladder_dicom)) {
+    dicom_data_bladder <- read_dicom_try(dir_bladder_dicom)
+  }
 
 }
