@@ -53,80 +53,80 @@ test_that("DICOM standard - for CRAN", {
 })
 
 test_that("DICOM header as matrix - for CRAN", {
-  expect_equal(ncol(dicom_header_as_matrix(sample_dicom_img)), 7)
-  expect_error(dicom_header_as_matrix(dicom_data_sbarre_heart_mr, 2))
-  expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_heart_mr)), 5)
-  expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_heart_nm)), 5)
-  expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_execho)), 5)
-  expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_ort)), 5)
-  expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_brain)), 5)
-  expect_equal(ncol(dicom_header_as_matrix(dicom_data_dclunie_scsgreek)), 5)
-  expect_equal(ncol(dicom_header_as_matrix(dicom_data_dclunie_image)), 5)
-  expect_equal(ncol(dicom_header_as_matrix(sample_dicom_img)), 7)
+  expression_try(sample_dicom_img, expect_equal(ncol(dicom_header_as_matrix(sample_dicom_img)), 7))
+  expression_try(dicom_data_sbarre_heart_mr, expect_error(dicom_header_as_matrix(dicom_data_sbarre_heart_mr, 2)))
+  expression_try(dicom_data_sbarre_heart_mr, expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_heart_mr)), 5))
+  expression_try(dicom_data_sbarre_heart_nm, expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_heart_nm)), 5))
+  expression_try(dicom_data_sbarre_execho, expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_execho)), 5))
+  expression_try(dicom_data_sbarre_ort, expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_ort)), 5))
+  expression_try(dicom_data_sbarre_brain, expect_equal(ncol(dicom_header_as_matrix(dicom_data_sbarre_brain)), 5))
+  expression_try(dicom_data_dclunie_scsgreek, expect_equal(ncol(dicom_header_as_matrix(dicom_data_dclunie_scsgreek)), 5))
+  expression_try(dicom_data_dclunie_image, expect_equal(ncol(dicom_header_as_matrix(dicom_data_dclunie_image)), 5))
+  expression_try(sample_dicom_img, expect_equal(ncol(dicom_header_as_matrix(sample_dicom_img)), 7))
 })
 
 test_that("Number of slices - for CRAN", {
-  expect_equal(num_slices(sample_dicom_img), 3)
-  expect_equal(num_slices(dicom_data_sbarre_ort), 1)
-  expect_equal(num_slices(dicom_data_sbarre_heart_mr), 1)
-  expect_equal(num_slices(dicom_data_sbarre_heart_nm), 1)
-  expect_equal(num_slices(dicom_data_sbarre_execho), 1)
-  expect_equal(num_slices(dicom_data_sbarre_brain), 1)
-  expect_equal(num_slices(dicom_data_sbarre_knee), 1)
-  expect_equal(num_slices(dicom_data_sbarre_head), 1)
-  expect_equal(num_slices(dicom_data_dclunie_scsgreek), 1)
-  expect_equal(num_slices(dicom_data_dclunie_image), 1)
-  expect_equal(num_slices(sample_dicom_img), 3)
+  expression_try(sample_dicom_img, expect_equal(num_slices(sample_dicom_img), 3))
+  expression_try(dicom_data_sbarre_ort, expect_equal(num_slices(dicom_data_sbarre_ort), 1))
+  expression_try(dicom_data_sbarre_heart_mr, expect_equal(num_slices(dicom_data_sbarre_heart_mr), 1))
+  expression_try(dicom_data_sbarre_heart_nm, expect_equal(num_slices(dicom_data_sbarre_heart_nm), 1))
+  expression_try(dicom_data_sbarre_execho, expect_equal(num_slices(dicom_data_sbarre_execho), 1))
+  expression_try(dicom_data_sbarre_brain, expect_equal(num_slices(dicom_data_sbarre_brain), 1))
+  expression_try(dicom_data_sbarre_knee, expect_equal(num_slices(dicom_data_sbarre_knee), 1))
+  expression_try(dicom_data_sbarre_head, expect_equal(num_slices(dicom_data_sbarre_head), 1))
+  expression_try(dicom_data_dclunie_scsgreek, expect_equal(num_slices(dicom_data_dclunie_scsgreek), 1))
+  expression_try(dicom_data_dclunie_image, expect_equal(num_slices(dicom_data_dclunie_image), 1))
+  expression_try(sample_dicom_img, expect_equal(num_slices(sample_dicom_img), 3))
 })
 
 test_that("Image dimensions - for CRAN", {
-  expect_equal(img_dimensions(sample_dicom_img), c(256, 256, 3))
-  expect_equal(img_dimensions(dicom_data_sbarre_brain), c(512, 512, 1))
+  expression_try(sample_dicom_img, expect_equal(img_dimensions(sample_dicom_img), c(256, 256, 3)))
+  expression_try(dicom_data_sbarre_brain, expect_equal(img_dimensions(dicom_data_sbarre_brain), c(512, 512, 1)))
   expect_error(img_dimensions(dicom_data_sbarre_ort))
   expect_error(img_dimensions(dicom_data_sbarre_knee))
   expect_error(img_dimensions(dicom_data_sbarre_head))
   expect_error(img_dimensions(dicom_data_sbarre_execho))
   expect_error(img_dimensions(dicom_data_dclunie_scsgreek))
   expect_error(img_dimensions(dicom_data_dclunie_image))
-  expect_equal(img_dimensions(sample_dicom_img), c(256, 256, 3))
+  expression_try(sample_dicom_img, expect_equal(img_dimensions(sample_dicom_img), c(256, 256, 3)))
 })
 
 test_that("DICOM header fields - for CRAN", {
-  expect_true("SpecificCharacterSet" %in% header_fields(sample_dicom_img))
-  expect_true("StudyInstanceUID" %in% header_fields(dicom_data_dclunie_scsgreek))
-  expect_true("StudyInstanceUID" %in% header_fields(dicom_data_dclunie_image))
-  expect_true("SliceThickness" %in% header_fields(dicom_data_sbarre_heart_nm))
-  expect_true("Manufacturer" %in% header_fields(dicom_data_sbarre_head))
-  expect_true("SpecificCharacterSet" %in% header_fields(sample_dicom_img))
+  expression_try(sample_dicom_img, expect_true("SpecificCharacterSet" %in% header_fields(sample_dicom_img)))
+  expression_try(dicom_data_dclunie_scsgreek, expect_true("StudyInstanceUID" %in% header_fields(dicom_data_dclunie_scsgreek)))
+  expression_try(dicom_data_dclunie_image, expect_true("StudyInstanceUID" %in% header_fields(dicom_data_dclunie_image)))
+  expression_try(dicom_data_sbarre_heart_nm, expect_true("SliceThickness" %in% header_fields(dicom_data_sbarre_heart_nm)))
+  expression_try(dicom_data_sbarre_head, expect_true("Manufacturer" %in% header_fields(dicom_data_sbarre_head)))
+  expression_try(sample_dicom_img, expect_true("SpecificCharacterSet" %in% header_fields(sample_dicom_img)))
 })
 
 test_that("DICOM header values - for CRAN", {
-  expect_equal(header_value(sample_dicom_img, "InstanceCreatorUID")[[1]], "1.3.6.1.4.1.5962.3")
-  expect_equal(header_value(sample_dicom_img, "GroupLength")[[3]], 192)
-  expect_equal(header_value(dicom_data_sbarre_brain, "SliceThickness"), 10.0)
-  expect_equal(header_value(dicom_data_sbarre_head, "SpatialResolution"), "1.145833 0.859375")
-  expect_equal(header_value(dicom_data_sbarre_knee, "HighBit"), 15)
-  expect_equal(header_value(dicom_data_sbarre_ort, "PhotometricInterpretation"), "MONOCHROME2")
-  expect_equal(header_value(dicom_data_sbarre_heart_mr, "NumberOfFrames"), 16)
-  expect_equal(header_value(dicom_data_sbarre_heart_nm, "NumberOfFrames"), 13)
-  expect_equal(header_value(dicom_data_sbarre_execho, "NumberOfFrames"), 8)
-  expect_equal(header_value(dicom_data_dclunie_scsgreek, "InstanceNumber"), 1)
-  expect_equal(header_value(dicom_data_dclunie_scsgreek, "PhotometricInterpretation"), "MONOCHROME2")
-  expect_equal(header_value(sample_dicom_img, "InstanceCreatorUID")[[1]], "1.3.6.1.4.1.5962.3")
-  expect_equal(header_value(sample_dicom_img, "GroupLength")[[3]], 192)
+  expression_try(sample_dicom_img, expect_equal(header_value(sample_dicom_img, "InstanceCreatorUID")[[1]], "1.3.6.1.4.1.5962.3"))
+  expression_try(sample_dicom_img, expect_equal(header_value(sample_dicom_img, "GroupLength")[[3]], 192))
+  expression_try(dicom_data_sbarre_brain, expect_equal(header_value(dicom_data_sbarre_brain, "SliceThickness"), 10.0))
+  expression_try(dicom_data_sbarre_head, expect_equal(header_value(dicom_data_sbarre_head, "SpatialResolution"), "1.145833 0.859375"))
+  expression_try(dicom_data_sbarre_knee, expect_equal(header_value(dicom_data_sbarre_knee, "HighBit"), 15))
+  expression_try(dicom_data_sbarre_ort, expect_equal(header_value(dicom_data_sbarre_ort, "PhotometricInterpretation"), "MONOCHROME2"))
+  expression_try(dicom_data_sbarre_heart_mr, expect_equal(header_value(dicom_data_sbarre_heart_mr, "NumberOfFrames"), 16))
+  expression_try(dicom_data_sbarre_heart_nm, expect_equal(header_value(dicom_data_sbarre_heart_nm, "NumberOfFrames"), 13))
+  expression_try(dicom_data_sbarre_execho, expect_equal(header_value(dicom_data_sbarre_execho, "NumberOfFrames"), 8))
+  expression_try(dicom_data_dclunie_scsgreek, expect_equal(header_value(dicom_data_dclunie_scsgreek, "InstanceNumber"), 1))
+  expression_try(dicom_data_dclunie_scsgreek, expect_equal(header_value(dicom_data_dclunie_scsgreek, "PhotometricInterpretation"), "MONOCHROME2"))
+  expression_try(sample_dicom_img, expect_equal(header_value(sample_dicom_img, "InstanceCreatorUID")[[1]], "1.3.6.1.4.1.5962.3"))
+  expression_try(sample_dicom_img, expect_equal(header_value(sample_dicom_img, "GroupLength")[[3]], 192))
 })
 
 test_that("Constant header values - for CRAN", {
-  expect_equal(dicom_constant_header_values(sample_dicom_img)[["StudyDate"]], 20030505)
-  expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_ort)), length(header_fields(dicom_data_sbarre_ort)))
-  expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_ort)), nrow(dicom_header_as_matrix(dicom_data_sbarre_ort)) - 6) # GroupLength is included 6 times
-  expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_heart_mr)), length(header_fields(dicom_data_sbarre_heart_mr)))
-  expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_heart_nm)), length(header_fields(dicom_data_sbarre_heart_nm)))
-  expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_execho)), length(header_fields(dicom_data_sbarre_execho)))
-  expect_equal(length(dicom_constant_header_values(dicom_data_dclunie_scsgreek)), length(header_fields(dicom_data_dclunie_scsgreek)))
-  expect_equal(length(dicom_constant_header_values(dicom_data_dclunie_scsgreek)), nrow(dicom_header_as_matrix(dicom_data_dclunie_scsgreek)))
-  expect_equal(length(dicom_constant_header_values(dicom_data_dclunie_image)), length(header_fields(dicom_data_dclunie_image)))
-  expect_equal(length(dicom_constant_header_values(dicom_data_dclunie_image)), nrow(dicom_header_as_matrix(dicom_data_dclunie_image)))
+  expression_try(sample_dicom_img, expect_equal(dicom_constant_header_values(sample_dicom_img)[["StudyDate"]], 20030505))
+  expression_try(dicom_data_sbarre_ort, expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_ort)), length(header_fields(dicom_data_sbarre_ort))))
+  expression_try(dicom_data_sbarre_ort, expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_ort)), nrow(dicom_header_as_matrix(dicom_data_sbarre_ort)) - 6)) # GroupLength is included 6 times
+  expression_try(dicom_data_sbarre_heart_mr, expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_heart_mr)), length(header_fields(dicom_data_sbarre_heart_mr))))
+  expression_try(dicom_data_sbarre_heart_nm, expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_heart_nm)), length(header_fields(dicom_data_sbarre_heart_nm))))
+  expression_try(dicom_data_sbarre_execho, expect_equal(length(dicom_constant_header_values(dicom_data_sbarre_execho)), length(header_fields(dicom_data_sbarre_execho))))
+  expression_try(dicom_data_dclunie_scsgreek, expect_equal(length(dicom_constant_header_values(dicom_data_dclunie_scsgreek)), length(header_fields(dicom_data_dclunie_scsgreek))))
+  expression_try(dicom_data_dclunie_scsgreek, expect_equal(length(dicom_constant_header_values(dicom_data_dclunie_scsgreek)), nrow(dicom_header_as_matrix(dicom_data_dclunie_scsgreek))))
+  expression_try(dicom_data_dclunie_image, expect_equal(length(dicom_constant_header_values(dicom_data_dclunie_image)), length(header_fields(dicom_data_dclunie_image))))
+  expression_try(dicom_data_dclunie_image, expect_equal(length(dicom_constant_header_values(dicom_data_dclunie_image)), nrow(dicom_header_as_matrix(dicom_data_dclunie_image))))
 })
 
 
@@ -134,6 +134,8 @@ test_that("Constant header values - for CRAN", {
 test_that("DICOM metadata not run on CRAN", {
 
   skip_on_cran()
+  testthat::skip_on_travis()
+  testthat::skip_on_appveyor()
 
   # Number of slices
   expect_equal(num_slices(dicom_data_qin_hn_sr), 0)
